summaryrefslogtreecommitdiffstats
path: root/cpukit/posix/src/semtimedwait.c
diff options
context:
space:
mode:
authorSebastian Huber <sebastian.huber@embedded-brains.de>2015-07-28 14:45:42 +0200
committerSebastian Huber <sebastian.huber@embedded-brains.de>2015-07-28 14:54:51 +0200
commit21789a2117f7485000e0d88c3f76a6b9d507bb5a (patch)
treef14a8eee3d9c10fd673c43f55f7a50d9b5b58b05 /cpukit/posix/src/semtimedwait.c
parentm68k: Include proper header file (diff)
downloadrtems-21789a2117f7485000e0d88c3f76a6b9d507bb5a.tar.bz2
score: Rename _POSIX_Absolute_timeout_to_ticks()
Rename _POSIX_Absolute_timeout_to_ticks() to _TOD_Absolute_timeout_to_ticks() and move it to the score directory. Delete empty <rtems/posix/time.h>.
Diffstat (limited to 'cpukit/posix/src/semtimedwait.c')
-rw-r--r--cpukit/posix/src/semtimedwait.c18
1 files changed, 9 insertions, 9 deletions
diff --git a/cpukit/posix/src/semtimedwait.c b/cpukit/posix/src/semtimedwait.c
index 6427f70436..58d6e24ed9 100644
--- a/cpukit/posix/src/semtimedwait.c
+++ b/cpukit/posix/src/semtimedwait.c
@@ -27,8 +27,8 @@
#include <limits.h>
#include <rtems/system.h>
+#include <rtems/score/todimpl.h>
#include <rtems/posix/semaphoreimpl.h>
-#include <rtems/posix/time.h>
#include <rtems/seterr.h>
/*
@@ -44,7 +44,7 @@ int sem_timedwait(
{
Watchdog_Interval ticks;
bool do_wait = true;
- POSIX_Absolute_timeout_conversion_results_t status;
+ TOD_Absolute_timeout_conversion_results status;
int lock_status;
/*
@@ -56,12 +56,12 @@ int sem_timedwait(
* then we do a polling operation and convert the UNSATISFIED
* status into the appropriate error.
*
* If the status is POSIX_ABSOLUTE_TIMEOUT_INVALID,
* POSIX_ABSOLUTE_TIMEOUT_IS_IN_PAST, or POSIX_ABSOLUTE_TIMEOUT_IS_NOW,
* then we should not wait.
*/
- status = _POSIX_Absolute_timeout_to_ticks( abstime, &ticks );
- if ( status != POSIX_ABSOLUTE_TIMEOUT_IS_IN_FUTURE )
+ status = _TOD_Absolute_timeout_to_ticks( abstime, &ticks );
+ if ( status != TOD_ABSOLUTE_TIMEOUT_IS_IN_FUTURE )
do_wait = false;
lock_status = _POSIX_Semaphore_Wait_support( sem, do_wait, ticks );
@@ -73,10 +73,10 @@ int sem_timedwait(
* make sure the right reason is returned.
*/
if ( !do_wait && (lock_status == EBUSY) ) {
- if ( lock_status == POSIX_ABSOLUTE_TIMEOUT_INVALID )
+ if ( lock_status == TOD_ABSOLUTE_TIMEOUT_INVALID )
rtems_set_errno_and_return_minus_one( EINVAL );
- if ( lock_status == POSIX_ABSOLUTE_TIMEOUT_IS_IN_PAST ||
- lock_status == POSIX_ABSOLUTE_TIMEOUT_IS_NOW )
+ if ( lock_status == TOD_ABSOLUTE_TIMEOUT_IS_IN_PAST ||
+ lock_status == TOD_ABSOLUTE_TIMEOUT_IS_NOW )
rtems_set_errno_and_return_minus_one( ETIMEDOUT );
}
@@ -56,12 +56,12 @@ int sem_timedwait(
* status into the appropriate error.
*
- * If the status is POSIX_ABSOLUTE_TIMEOUT_INVALID,
- * POSIX_ABSOLUTE_TIMEOUT_IS_IN_PAST, or POSIX_ABSOLUTE_TIMEOUT_IS_NOW,
+ * If the status is TOD_ABSOLUTE_TIMEOUT_INVALID,
+ * TOD_ABSOLUTE_TIMEOUT_IS_IN_PAST, or TOD_ABSOLUTE_TIMEOUT_IS_NOW,
* then we should not wait.
*/